@@ -455,6 +455,18 @@ public:
     inline bool puts(const char *str)
         {return put(str, strlen(str));};
 
+    inline Digest &operator<<(const char *str)
+        {puts(str); return *this;}
+
+    inline Digest &operator<<(int16_t value)
+        {int16_t v = htons(value); put(&v, 2); return *this;}
+
+    inline Digest &operator<<(int32_t value)
+        {int32_t v = htonl(value); put(&v, 4); return *this;}
+
+    inline Digest &operator<<(const PrintProtocol& p)
+        {const char *cp = p._print(); if(cp) puts(cp); return *this;}
+
     bool put(const void *memory, size_t size);
 
     inline unsigned size() const
@@ -514,6 +526,91 @@ public:
     static String uuid(const char *name, const unsigned char *ns = NULL);
 };
 
+/**
+ * A cryptographic message authentication code class.  This class can support 
+ * md5 digests, sha1, sha256, etc, depending on what the underlying library 
+ * supports.
+ * @author David Sugar <dyfet@gnutelephony.org>
+ */
+class __SHARED HMAC
+{
+private:
+    void *context;
+
+    union {
+        const void *hmactype;
+        int hmacid;
+    };
+
+    unsigned bufsize;
+    unsigned char buffer[MAX_DIGEST_HASHSIZE / 8];
+    char textbuf[MAX_DIGEST_HASHSIZE / 8 + 1];
+
+protected:
+    void release(void);
+
+public:
+    HMAC(const char *digest, const char *key, size_t keylen = 0);
+
+    HMAC();
+
+    ~HMAC();
+
+    inline bool puts(const char *str)
+        {return put(str, strlen(str));};
+
+    inline HMAC &operator<<(const char *str)
+        {puts(str); return *this;}
+
+    inline HMAC &operator<<(int16_t value)
+        {int16_t v = htons(value); put(&v, 2); return *this;}
+
+    inline HMAC &operator<<(int32_t value)
+        {int32_t v = htonl(value); put(&v, 4); return *this;}
+
+    inline HMAC &operator<<(const PrintProtocol& p)
+        {const char *cp = p._print(); if(cp) puts(cp); return *this;}
+
+    bool put(const void *memory, size_t size);
+
+    inline unsigned size() const
+        {return bufsize;};
+
+    const unsigned char *get(void);
+
+    const char *c_str(void);
+
+    inline String str(void)
+        {return String(c_str());};
+
+    inline operator String()
+        {return String(c_str());};
+
+    void set(const char *digest, const char *key, size_t len);
+
+    inline bool operator *=(const char *text)
+        {return puts(text);};
+
+    inline bool operator +=(const char *text)
+        {return puts(text);};
+
+    inline const char *operator*()
+        {return c_str();};
+
+    inline bool operator!() const
+        {return !bufsize && context == NULL;};
+
+    inline operator bool() const
+        {return bufsize > 0 || context != NULL;};
+
+    /**
+     * Test to see if a specific digest type is supported.
+     * @param name of digest we want to check.
+     * @return true if supported, false if not.
+     */
+    static bool has(const char *name);
+};
+
 /**
  * Cryptographically relevant random numbers.  This is used both to gather
  * entropy pools and pseudo-random values.
@@ -609,6 +706,11 @@ typedef SSLBuffer ssl_t;
  */
 typedef Digest digest_t;
 
+/**
+ * Convenience type for generic digests.
+ */
+typedef HMAC hmac_t;
+
 /**
  * Convenience type for generic ciphers.
  */
@@ -672,6 +774,190 @@ public:
         {return bio != NULL;}
 };
 
+/**
+ * A template to create a string array that automatically erases.
+ * This is a mini string/stringbuf class that supports a subset of
+ * functionality but does not require a complex supporting object.  Like
+ * stringbuf, this can be used to create local string variables.  When
+ * the object falls out of scope it's memory is reset.
+ * @author David Sugar <dyfet@gnutelephony.org>
+ */
+template<size_t S>
+class keystring
+{
+private:
+    char buffer[S];
+
+    /**
+     * Disable copy constructor.
+     */
+    inline keystring(const keystring& copy) {};
+
+public:
+    /**
+     * Create a new character buffer with an empty string.
+     */
+    inline keystring()
+        {buffer[0] = 0;}
+
+    /**
+     * Create a character buffer with assigned text.  If the text is
+     * larger than the size of the object, it is truncated.
+     * @param text to assign.
+     */
+    inline keystring(const char *text)
+        {String::set(buffer, S, text);}
+
+    /**
+     * Clear memory when destroyed.
+     */
+    inline ~keystring()
+        {memset(buffer, 0, S);}
+
+    /**
+     * Clear current key memory.
+     */
+    inline void clear(void)
+        {memset(buffer, 0, S);}
+
+    /**
+     * Assign null terminated text to the object.
+     * @param text to assign.
+     */
+    inline void operator=(const char *text)
+        {String::set(buffer, S, text);}
+
+    /**
+     * Concatenate text into the object.  If the text is larger than the
+     * size of the object, then it is truncated.
+     * @param text to append.
+     */
+    inline void operator+=(const char *text)
+        {String::add(buffer, S, text);}
+
+    /**
+     * Test if data is contained in the object.
+     * @return true if there is text.
+     */
+    inline operator bool() const
+        {return buffer[0];}
+
+    /**
+     * Test if the object is empty.
+     * @return true if the object is empty.
+     */
+    inline bool operator!() const
+        {return buffer[0] == 0;}
+
+    /**
+     * Get text by casting reference.
+     * @return pointer to text in object.
+     */
+    inline operator char *()
+        {return buffer;}
+
+    /**
+     * Get text by object pointer reference.
+     * @return pointer to text in object.
+     */
+    inline char *operator*()
+        {return buffer;}
+
+    /**
+     * Array operator to get a character from the object.
+     * @param offset of character in string buffer.
+     * @return character at offset.
+     */
+    inline char& operator[](size_t offset) const
+        {return buffer[offset];}
+
+    /**
+     * Get a pointer to an offset in the object by expression operator.
+     * @param offset of character in string buffer.
+     * @return pointer to offset in object.
+     */
+    inline char *operator()(size_t offset)
+        {return buffer + offset;}
+
+    /**
+     * Get allocated size of the object.
+     * @return allocated size.
+     */
+    inline size_t size(void) const
+        {return S;}
+
+    /**
+     * Get current length of string.
+     * @return length of string.
+     */
+    inline size_t len(void) const
+        {return strlen(buffer);}
+};
+
+/**
+ * A template to create a random generated key of specified size.  The
+ * key memory is cleared when the object is destroyed.
+ * @author David Sugar <dyfet@gnutelephony.org>
+ */
+template<size_t S>
+class keyrandom
+{
+private:
+    unsigned char buffer[S];
+
+    /**
+     * Disable copy constructor.
+     */
+    inline keyrandom(const keyrandom& copy) {};
+
+public:
+    /**
+     * Create a new character buffer with an empty string.
+     */
+    inline keyrandom()
+        {Random::key(buffer, S);}
+
+    /**
+     * Clear memory when destroyed.
+     */
+    inline ~keyrandom()
+        {memset(buffer, 0, S);}
+
+    /**
+     * Update with new random key.
+     */
+    inline void update(void)
+        {Random::key(buffer, S);}
+
+    /**
+     * Clear current key memory.
+     */
+    inline void clear(void)
+        {memset(buffer, 0, S);}
+
+    /**
+     * Get text by casting reference.
+     * @return pointer to text in object.
+     */
+    inline operator unsigned char *()
+        {return buffer;}
+
+    /**
+     * Get text by object pointer reference.
+     * @return pointer to text in object.
+     */
+    inline unsigned char *operator*()
+        {return buffer;}
+
+    /**
+     * Get allocated size of the object.
+     * @return allocated size.
+     */
+    inline size_t size(void) const
+        {return S;}
+};
+
+
 #endif
 
 END_NAMESPACE
