@@ -17,29 +17,6 @@
 
 #include "local.h"
 
-Digest::Digest()
-{
-    hashtype = (void *)" ";
-    context = NULL;
-    bufsize = 0;
-    textbuf[0] = 0;
-}
-
-Digest::Digest(const char *type)
-{
-    hashtype = (void *)" ";
-    context = NULL;
-    bufsize = 0;
-    textbuf[0] = 0;
-
-    set(type);
-}
-
-Digest::~Digest()
-{
-    release();
-}
-
 bool Digest::has(const char *id)
 {
     if(eq_case(id, "md5"))
@@ -70,7 +47,7 @@ void Digest::set(const char *type)
 void Digest::release(void)
 {
 
-    if(context) {
+    if(context && hashtype) {
         switch(*((char *)hashtype)) {
         case 'm':
             delete (MD5_CTX*)context;
@@ -86,13 +63,12 @@ void Digest::release(void)
 
     bufsize = 0;
     textbuf[0] = 0;
-
-    hashtype = " ";
+    hashtype = NULL;
 }
 
 bool Digest::put(const void *address, size_t size)
 {
-    if(!context)
+    if(!context || !hashtype)
         return false;
 
     switch(*((char *)hashtype)) {
@@ -107,29 +83,23 @@ bool Digest::put(const void *address, size_t size)
     }
 }
 
-const char *Digest::c_str(void)
-{
-    if(!bufsize)
-        get();
-
-    return textbuf;
-}
-
 void Digest::reset(void)
 {
-    switch(*((char *)hashtype)) {
-    case 'm':
-        if(!context)
-            context = new MD5_CTX;
-        MD5Init((MD5_CTX*)context);
-        break;
-    case 's':
-        if(!context)
-            context = new SHA1_CTX;
-        SHA1Init((SHA1_CTX*)context);
-        break;
-    default:
-        break;
+    if(hashtype) {
+        switch(*((char *)hashtype)) {
+        case 'm':
+            if(!context)
+                context = new MD5_CTX;
+            MD5Init((MD5_CTX*)context);
+            break;
+        case 's':
+            if(!context)
+                context = new SHA1_CTX;
+            SHA1Init((SHA1_CTX*)context);
+            break;
+        default:
+            break;
+        }
     }
     bufsize = 0;
 }
@@ -138,7 +108,7 @@ void Digest::recycle(bool bin)
 {
     unsigned size = bufsize;
 
-    if(!context)
+    if(!context || !hashtype)
         return;
 
     switch(*((char *)hashtype)) {
@@ -191,7 +161,7 @@ const unsigned char *Digest::get(void)
     if(bufsize)
         return buffer;
 
-    if(!context)
+    if(!context || !hashtype)
         return NULL;
 
     switch(*((char *)hashtype)) {
@@ -216,33 +186,3 @@ const unsigned char *Digest::get(void)
     return buffer;
 }
 
-void Digest::uuid(char *str, const char *name, const unsigned char *ns)
-{
-    unsigned mask = 0x50;
-    const char *type = "sha1";
-    if(!has("sha1")) {
-        mask = 0x30;
-        type = "md5";
-    }
-
-    Digest md(type);
-    if(ns)
-        md.put(ns, 16);
-    md.puts(name);
-    unsigned char *buf = (unsigned char *)md.get();
-
-    buf[6] &= 0x0f;
-    buf[6] |= mask;
-    buf[8] &= 0x3f;
-    buf[8] |= 0x80;
-
-    String::hexdump(buf, str, "4-2-2-2-6");
-}
-
-String Digest::uuid(const char *name, const unsigned char *ns)
-{
-    char buf[38];
-    uuid(buf, name, ns);
-    return String(buf);
-}
-
